import { type ICalendarEventSourceSchema } from "@leight/calendar";
import { type InferSelectors } from "@leight/mantine";
import { type ISource } from "@leight/source";
import { Container } from "@mantine/core";
import { type ComponentProps, type ReactNode } from "react";
declare const useStyles: (params: void, options?: import("@mantine/core").UseStylesOptions<string> | undefined) => {
    classes: {
        calendar: string;
        calendarGrid: string;
        controlsGrid: string;
        controls: string;
        controlsLeft: string;
        controlsMiddle: string;
        controlsRight: string;
        controlsPrefix: string;
        controlsSuffix: string;
        header: string;
        cell: string;
        monthCell: string;
        yearCell: string;
        row: string;
        currentMonth: string;
        currentYear: string;
        currentWeek: string;
        currentDay: string;
        inRange: string;
        outOfRange: string;
    };
    cx: (...args: any) => string;
    theme: import("@mantine/core").MantineTheme;
};
export type ICalendarStyles = InferSelectors<typeof useStyles>;
export type ICalendarComponent<TSourceSchema extends ICalendarEventSourceSchema> = ((props: ICalendarComponent.IRenderProps<TSourceSchema>) => ReactNode) | ReactNode;
export declare namespace ICalendarComponent {
    interface IRenderProps<TSourceSchema extends ICalendarEventSourceSchema> {
        classes: ICalendarStyles;
        source?: ISource.IUseResult<TSourceSchema>;
        compact?: boolean;
    }
}
export interface ICalendarShellEvents<TSourceSchema extends ICalendarEventSourceSchema> {
    schema: TSourceSchema["DtoSchema"];
    Source: ISource<TSourceSchema>;
}
export interface ICalendarShellProps<TSourceSchema extends ICalendarEventSourceSchema> extends Omit<ComponentProps<typeof Container>, "children"> {
    events?: ICalendarShellEvents<TSourceSchema>;
    withControls?: boolean;
    controlsTopLeft?: ICalendarComponent<TSourceSchema>;
    controlsTopMiddle?: ICalendarComponent<TSourceSchema>;
    controlsTopRight?: ICalendarComponent<TSourceSchema>;
    controlsBottomLeft?: ICalendarComponent<TSourceSchema>;
    controlsBottomMiddle?: ICalendarComponent<TSourceSchema>;
    controlsBottomRight?: ICalendarComponent<TSourceSchema>;
    compact?: boolean;
    children: ICalendarComponent<TSourceSchema>;
}
/**
 * Styled shell for Calendar.
 */
export declare const CalendarShell: <TSourceSchema extends import("@leight/source").ISourceSchema<import("zod").ZodObject<{
    id: import("zod").ZodString;
}, "strip", import("zod").ZodTypeAny, {
    id: string;
}, {
    id: string;
}>, import("zod").ZodObject<{
    id: import("zod").ZodString;
    date: import("zod").ZodDate;
    prev: import("zod").ZodOptional<import("zod").ZodDate>;
    next: import("zod").ZodOptional<import("zod").ZodDate>;
}, "strip", import("zod").ZodTypeAny, {
    prev?: Date | undefined;
    next?: Date | undefined;
    date: Date;
    id: string;
}, {
    prev?: Date | undefined;
    next?: Date | undefined;
    date: Date;
    id: string;
}>, import("zod").ZodObject<{}, "strip", import("zod").ZodTypeAny, {}, {}>, import("zod").ZodObject<{}, "strip", import("zod").ZodTypeAny, {}, {}>, import("@leight/source").IToPatchSchema, import("@leight/source").IPatchSchema, import("zod").ZodObject<{
    id: import("zod").ZodOptional<import("zod").ZodString>;
    ids: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString, "many">>;
    fulltext: import("zod").ZodOptional<import("zod").ZodString>;
    withRange: import("zod").ZodOptional<import("zod").ZodObject<{
        from: import("zod").ZodDate;
        to: import("zod").ZodDate;
    }, "strip", import("zod").ZodTypeAny, {
        from: Date;
        to: Date;
    }, {
        from: Date;
        to: Date;
    }>>;
}, "strip", import("zod").ZodTypeAny, {
    id?: string | undefined;
    ids?: string[] | undefined;
    fulltext?: string | undefined;
    withRange?: {
        from: Date;
        to: Date;
    } | undefined;
}, {
    id?: string | undefined;
    ids?: string[] | undefined;
    fulltext?: string | undefined;
    withRange?: {
        from: Date;
        to: Date;
    } | undefined;
}>, import("@leight/source").ISortSchema, import("@leight/source").IParamsSchema> = import("@leight/source").ISourceSchema<import("zod").ZodObject<{
    id: import("zod").ZodString;
}, "strip", import("zod").ZodTypeAny, {
    id: string;
}, {
    id: string;
}>, import("zod").ZodObject<{
    id: import("zod").ZodString;
    date: import("zod").ZodDate;
    prev: import("zod").ZodOptional<import("zod").ZodDate>;
    next: import("zod").ZodOptional<import("zod").ZodDate>;
}, "strip", import("zod").ZodTypeAny, {
    prev?: Date | undefined;
    next?: Date | undefined;
    date: Date;
    id: string;
}, {
    prev?: Date | undefined;
    next?: Date | undefined;
    date: Date;
    id: string;
}>, import("zod").ZodObject<{}, "strip", import("zod").ZodTypeAny, {}, {}>, import("zod").ZodObject<{}, "strip", import("zod").ZodTypeAny, {}, {}>, import("@leight/source").IToPatchSchema, import("@leight/source").IPatchSchema, import("zod").ZodObject<{
    id: import("zod").ZodOptional<import("zod").ZodString>;
    ids: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodString, "many">>;
    fulltext: import("zod").ZodOptional<import("zod").ZodString>;
    withRange: import("zod").ZodOptional<import("zod").ZodObject<{
        from: import("zod").ZodDate;
        to: import("zod").ZodDate;
    }, "strip", import("zod").ZodTypeAny, {
        from: Date;
        to: Date;
    }, {
        from: Date;
        to: Date;
    }>>;
}, "strip", import("zod").ZodTypeAny, {
    id?: string | undefined;
    ids?: string[] | undefined;
    fulltext?: string | undefined;
    withRange?: {
        from: Date;
        to: Date;
    } | undefined;
}, {
    id?: string | undefined;
    ids?: string[] | undefined;
    fulltext?: string | undefined;
    withRange?: {
        from: Date;
        to: Date;
    } | undefined;
}>, import("@leight/source").ISortSchema, import("@leight/source").IParamsSchema>>({ events, withControls, controlsTopLeft, controlsTopMiddle, controlsTopRight, controlsBottomLeft, controlsBottomMiddle, controlsBottomRight, compact, children, ...props }: ICalendarShellProps<TSourceSchema>) => import("react/jsx-runtime").JSX.Element;
export {};
//# sourceMappingURL=CalendarShell.d.ts.map